@@ -1,5 +1,4 @@
 use crate::helpers;
-use owo_colors::OwoColorize;
 use std::path::{Path, PathBuf};
 
 fn library_locations() -> Vec<PathBuf> {
@@ -18,10 +17,9 @@ fn library_locations() -> Vec<PathBuf> {
 pub fn get_debug() {
     check_libdbus();
     check_daemon_capabilities();
-    println!(
-        "\nStill encountering issues?\nReport a bug at {}",
-        "todo.sr.ht/~grtcdr/citron".bold()
-    );
+    println!();
+    println!("Still encountering issues?");
+    println!("Report a bug at https://todo.sr.ht/~grtcdr/citron");
 }
 
 pub fn get_entries(path: &Path) -> Option<Vec<PathBuf>> {
@@ -49,9 +47,9 @@ fn check_libdbus() {
     });
 
     if found.is_some() {
-        println!("- Searching for libdbus: {}", "OK".green());
+        println!("- Searching for libdbus: OK");
     } else {
-        println!("- Searching for libdbus: {}", "FAILED".red());
+        println!("- Searching for libdbus: FAILED");
     }
 }
 
@@ -59,16 +57,13 @@ fn check_daemon_capabilities() {
     let capabilities = notify_rust::get_capabilities();
     if let Ok(capab) = capabilities {
         let mut list = vec![];
-        println!("- Identifying your daemon's capabilities: {}", "OK".green());
+        println!("- Identifying your daemon's capabilities: OK");
         for c in capab {
             list.push(c);
         }
         println!("  * {}", list.join(", "));
     } else {
-        println!(
-            "- Identifying your daemon's capabilities: {}",
-            "FAILED".red()
-        );
+        println!("- Identifying your daemon's capabilities: FAILED",);
         println!("  * Do you have a notification daemon running/installed?",);
         println!("  * Are you in a graphical session?");
     }
