@@ -6,6 +6,7 @@ use std::fmt;
 pub struct BatteryFormatter {
     percentage: u8,
     state: BatteryState,
+    format: String,
 }
 
 impl BatteryFormatter {
@@ -13,13 +14,28 @@ impl BatteryFormatter {
         Self {
             percentage: 0,
             state: BatteryState::Discharging,
+            format: String::new(),
         }
     }
 
+    pub fn from_config(&mut self, format: String) {
+        self.format = format
+            .replace("%p", &self.get_percentage())
+            .replace("%s", &self.get_state())
+    }
+
     pub fn set_percentage(&mut self, p: u8) {
         self.percentage = p;
     }
 
+    pub fn get_percentage(&self) -> String {
+        format!("{}%", self.percentage)
+    }
+
+    pub fn get_state(&self) -> String {
+        self.state.to_string()
+    }
+
     pub fn set_state(&mut self, s: BatteryState) {
         self.state = s;
     }
@@ -55,18 +71,20 @@ impl Iconize for BatteryFormatter {
 
 impl fmt::Display for BatteryFormatter {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        if !self.format.is_empty() {
+            return write!(f, "{}", self.format);
+        }
+
         if self.percentage == 100 {
             return write!(f, "State: Full");
         }
 
-        match self.state {
-            BatteryState::Charging => {
-                write!(f, "Percentage: {}%\nState: Charging", self.percentage)
-            }
-            BatteryState::Discharging => {
-                write!(f, "Percentage: {}%\nState: Discharging", self.percentage)
-            }
-        }
+        write!(
+            f,
+            "Percentage: {}\nState: {}",
+            self.get_percentage(),
+            self.get_state()
+        )
     }
 }
 
