@@ -7,6 +7,7 @@ pub struct NetworkFormatter {
     logical_address: Option<String>,
     rx_bytes: Option<usize>,
     tx_bytes: Option<usize>,
+    format: Option<String>,
 }
 
 impl NetworkFormatter {
@@ -15,6 +16,7 @@ impl NetworkFormatter {
             logical_address: None,
             rx_bytes: None,
             tx_bytes: None,
+            format: None,
         }
     }
 
@@ -41,6 +43,21 @@ impl NetworkFormatter {
     pub fn get_tx_bytes(&self) -> Option<ByteSize> {
         self.tx_bytes.map(|bytes| ByteSize::kb(bytes as u64 / 1024))
     }
+
+    pub fn from_config(&mut self, format: String) {
+        if let (Some(addr), Some(rx_b), Some(tx_b)) = (
+            self.get_logical_address(),
+            self.get_rx_bytes(),
+            self.get_tx_bytes(),
+        ) {
+            self.format = Some(
+                format
+                    .replace("%a", &addr)
+                    .replace("%t", &tx_b.to_string())
+                    .replace("%r", &rx_b.to_string()),
+            )
+        }
+    }
 }
 
 impl Iconize for NetworkFormatter {
@@ -54,6 +71,10 @@ impl Iconize for NetworkFormatter {
 
 impl fmt::Display for NetworkFormatter {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        if let Some(format) = &self.format {
+            return writeln!(f, "{}", format);
+        }
+
         if let Some(addr) = &self.get_logical_address() {
             writeln!(f, "Local IP: {}", addr);
         }
