@@ -1,6 +1,4 @@
-use super::Config;
 use linicon::lookup_icon;
-use owo_colors::OwoColorize;
 use std::path::PathBuf;
 
 pub struct Icon {
@@ -62,13 +60,9 @@ impl Icon {
         themes
     }
 
-    pub fn set_theme(&mut self, config: Option<&Config>) {
-        if let Some(conf) = config {
-            if let Some(icon) = conf.get_icon() {
-                if let Some(theme) = icon.get_theme() {
-                    self.theme = theme;
-                }
-            }
+    pub fn set_theme(&mut self, theme: Option<String>) {
+        if let Some(t) = theme {
+            self.theme = t;
         }
     }
 
@@ -83,17 +77,13 @@ impl Icon {
                     Ok(i) => self.path = i.path,
                     _ => {
                         // The requested icon theme does not exist.
-                        eprintln!(
-                            "{}: {} doesn't exist.",
-                            "Warning".yellow().bold(),
-                            self.theme.cyan()
-                        );
+                        eprintln!("Warning: \"{}\" doesn't exist.", &self.theme);
                         // Print a list of usable themes.
-                        eprintln!("{}", "Pick a theme from this list:".bold());
+                        eprintln!("Pick a theme from this list:");
                         self.get_available_themes()
                             .into_iter()
-                            .filter(|x| !x.eq("default"))
-                            .for_each(|x| eprintln!(" {} {}", ">".blue(), x));
+                            .filter(|t| !t.eq("default"))
+                            .for_each(|t| eprintln!(" > {}", t));
                     }
                 }
 
@@ -102,10 +92,8 @@ impl Icon {
 
             // The requested icon does not exist for the given theme.
             eprintln!(
-                "{}: {} doesn't exist for {}.",
-                "Warning".yellow().bold(),
-                icon_name.purple(),
-                self.theme.cyan()
+                "Warning: \"{}\" doesn't exist for \"{}\".",
+                icon_name, &self.theme
             )
         }
     }
