@@ -18,17 +18,41 @@ impl fmt::Display for CommandError {
 
 #[derive(StructOpt, Debug, Clone)]
 pub enum Command {
-    #[structopt(visible_alias = "B", about = "Show a backlight notification", settings = &[AppSettings::ColoredHelp, AppSettings::DisableHelpFlags, AppSettings::DisableVersion])]
+    #[structopt(
+        visible_alias = "B",
+        about =  "Show a backlight notification", 
+        settings = &[AppSettings::ColoredHelp, AppSettings::DisableHelpFlags, AppSettings::DisableVersion]
+    )]
     Backlight,
-    #[structopt(visible_alias = "b", about = "Show a backlight notification", settings = &[AppSettings::ColoredHelp, AppSettings::DisableHelpFlags, AppSettings::DisableVersion])]
+    #[structopt(
+        visible_alias = "b",
+        about = "Show a battery notification", 
+        settings = &[AppSettings::ColoredHelp, AppSettings::DisableHelpFlags, AppSettings::DisableVersion]
+    )]
     Battery,
-    #[structopt(visible_alias = "n", about = "Show a backlight notification", settings = &[AppSettings::ColoredHelp, AppSettings::DisableHelpFlags, AppSettings::DisableVersion])]
+    #[structopt(
+        visible_alias = "n",
+        about = "Show a network notification",
+        settings = &[AppSettings::ColoredHelp, AppSettings::DisableHelpFlags, AppSettings::DisableVersion]
+    )]
     Network,
-    #[structopt(visible_alias = "u", about = "Show a backlight notification", settings = &[AppSettings::ColoredHelp, AppSettings::DisableHelpFlags, AppSettings::DisableVersion])]
+    #[structopt(
+        visible_alias = "u",
+        about = "Show an uptime notification",
+        settings = &[AppSettings::ColoredHelp, AppSettings::DisableHelpFlags, AppSettings::DisableVersion]
+    )]
     Uptime,
-    #[structopt(visible_alias = "m", about = "Show a backlight notification", settings = &[AppSettings::ColoredHelp, AppSettings::DisableHelpFlags, AppSettings::DisableVersion])]
+    #[structopt(
+        visible_alias = "m",
+        about = "Show a memory notification",
+        settings = &[AppSettings::ColoredHelp, AppSettings::DisableHelpFlags, AppSettings::DisableVersion]
+    )]
     Memory,
-    #[structopt(visible_alias = "d", about = "Show a backlight notification", settings = &[AppSettings::ColoredHelp, AppSettings::DisableHelpFlags, AppSettings::DisableVersion])]
+    #[structopt(
+        visible_alias = "d",
+        about = "Show a date notification",
+        settings = &[AppSettings::ColoredHelp, AppSettings::DisableHelpFlags, AppSettings::DisableVersion]
+    )]
     Date,
 }
 
