@@ -26,91 +26,76 @@ pub fn uptime(icon: &mut Icon) -> Result<String, ReadoutError> {
     let readout = GeneralReadout::new();
     let fmt = UptimeFormatter::from(readout.uptime()?);
     fmt.set_icon(icon);
-
     Ok(fmt.to_string())
 }
 
-pub fn network(config: Option<&Config>, icon: &mut Icon) -> Result<String, ReadoutError> {
+pub fn network(config: &Config, icon: &mut Icon) -> Result<String, ReadoutError> {
     let mut fmt = NetworkFormatter::new();
     let readout = NetworkReadout::new();
 
-    if let Some(conf) = config {
-        if let Some(network) = conf.get_network() {
-            if let Some(interface) = network.get_interface() {
-                let ifname = Some(interface.as_str());
-                if let Ok(address) = readout.logical_address(ifname) {
-                    fmt.set_logical_address(address);
-                }
+    if let Some(network) = config.get_network() {
+        if let Some(interface) = network.get_interface() {
+            let ifname = Some(interface.as_str());
 
-                if let Ok(rx_bytes) = readout.rx_bytes(ifname) {
-                    fmt.set_rx_bytes(rx_bytes);
-                }
+            match readout.logical_address(ifname) {
+                Ok(addr) => fmt.set_logical_address(addr),
+                Err(e) => return Err(ReadoutError::Other(e.to_string())),
+            }
 
-                if let Ok(tx_bytes) = readout.tx_bytes(ifname) {
-                    fmt.set_tx_bytes(tx_bytes);
-                }
+            if let Ok(bytes) = readout.rx_bytes(ifname) {
+                fmt.set_rx_bytes(bytes);
+            }
+
+            if let Ok(tx_bytes) = readout.tx_bytes(ifname) {
+                fmt.set_tx_bytes(tx_bytes);
+            }
+
+            if let Some(format) = network.get_format() {
+                fmt.from_config(format);
             }
         }
     }
 
     fmt.set_icon(icon);
-
     Ok(fmt.to_string())
 }
 
 pub fn memory(icon: &mut Icon) -> Result<String, ReadoutError> {
     let mut fmt = MemoryFormatter::new();
     let readout = MemoryReadout::new();
-
     fmt.set_total(readout.total()?);
     fmt.set_used(readout.used()?);
     fmt.set_percentage();
     fmt.set_icon(icon);
-
     Ok(fmt.to_string())
 }
 
-pub fn battery(config: Option<&Config>, icon: &mut Icon) -> Result<String, ReadoutError> {
+pub fn battery(config: &Config, icon: &mut Icon) -> Result<String, ReadoutError> {
     let mut fmt = BatteryFormatter::new();
     let readout = BatteryReadout::new();
-    let mut with_format = false;
 
-    if let Some(conf) = config {
-        if let Some(bat) = conf.get_battery() {
-            if let Some(format) = bat.get_format() {
-                with_format = true;
-                if format.contains("%p") {
-                    fmt.set_percentage(readout.percentage()?);
-                }
-                if format.contains("%s") {
-                    fmt.set_state(readout.status()?);
-                }
-                fmt.from_config(format);
-            }
+    fmt.set_percentage(readout.percentage()?);
+    fmt.set_state(readout.status()?);
+    fmt.set_icon(icon);
+
+    if let Some(bat) = config.get_battery() {
+        if let Some(format) = bat.get_format() {
+            fmt.from_config(format);
         }
     }
 
-    if !with_format {
-        fmt.set_percentage(readout.percentage()?);
-        fmt.set_state(readout.status()?);
-    }
-
-    fmt.set_icon(icon);
-
     Ok(fmt.to_string())
 }
 
 pub fn backlight(icon: &mut Icon) -> Result<String, ReadoutError> {
     let mut fmt = BacklightFormatter::new();
     let readout = GeneralReadout::new();
-
     fmt.set_percentage(readout.backlight()?);
     fmt.set_icon(icon);
-
     Ok(fmt.to_string())
 }
 
-pub fn date(config: Option<&Config>, icon: &mut Icon) -> Result<String, ReadoutError> {
+pub fn date(config: &Config, icon: &mut Icon) -> Result<String, ReadoutError> {
     let mut fmt = DateFormatter::new();
     if let Some(readout) = helpers::utc_from_timezone() {
         let hour = readout.hour12();
@@ -121,21 +106,18 @@ pub fn date(config: Option<&Config>, icon: &mut Icon) -> Result<String, ReadoutE
         fmt.set_meridiem(hour.0);
         fmt.set_hour(hour.1);
 
-        if let Some(conf) = config {
-            if let Some(date) = conf.get_date() {
-                if date.is_railway() {
-                    let hour = readout.hour();
-                    fmt.set_hour(hour);
-                }
+        if let Some(date) = config.get_date() {
+            if date.is_railway() {
+                let hour = readout.hour();
+                fmt.set_hour(hour);
+            }
 
-                if let Some(format) = date.get_format() {
-                    fmt.from_config(format);
-                }
+            if let Some(format) = date.get_format() {
+                fmt.from_config(format);
             }
         }
 
         fmt.set_icon(icon);
-
         return Ok(fmt.to_string());
     }
 
